/**
 * Convert number of bytes into a human-readable size
 *
 * @param {number} bytes Number of bytes
 * @param {number} decimals Decimal places to preserve
 * @return {string} Formated size
 */
export declare function formatBytes(bytes: number, decimals?: number): string;
/**
 * Extract numbers from a string & create a formated phone number: +1 (123) 456-7890
 *
 * @param {string} number String that will be parsed for numbers
 * @return {string} Formated phone number
 */
export declare function formatPhoneNumber(number: string): string;
/**
 * Insert a string into another string at a given position
 *
 * @example
 * ```js
 * console.log(insertAt('Hello world!', ' glorious', 5);
 * // Output: Hello glorious world!
 * ```
 *
 * @param {string} target - Parent string you want to modify
 * @param {string} str - Value that will be injected to parent
 * @param {number} index - Position to inject string at
 * @returns {string} - New string
 */
export declare function insertAt(target: string, str: string, index: number): String;
/**
 * Add padding to string
 *
 * @example
 * ```js
 * const now = new Date();
 * const padded = now.getHours() + ':' + pad(now.getMinutes(), 2, '0');
 * console.log(padded); // Output: "2:05"
 * ```
 *
 * @param text Text that will be padded
 * @param {number} length Target length
 * @param {string} char Character to use as padding, defaults to space
 * @param {boolean} start Will pad start of text if true, or the end if false
 * @return {string} Padded string
 * @deprecated Please use `String.padStart` & `String.padEnd`
 */
export declare function pad(text: any, length: number, char?: string, start?: boolean): any;
/**
 * Generate a random hexadecimal value
 *
 * @param {number} length Number of hexadecimal place values
 * @return {string} Hexadecimal number as a string
 */
export declare function randomHex(length: number): string;
/**
 * Generate a string of random characters.
 *
 * @example
 * ```ts
 * const random = randomString();
 * const randomByte = randomString(8, "01")
 * ```
 *
 * @param {number} length - length of generated string
 * @param {string} pool - character pool to generate string from
 * @return {string} generated string
 */
export declare function randomString(length: number, pool?: string): string;
/**
 * Generate a random string with fine control over letters, numbers & symbols
 *
 * @example
 * ```ts
 * const randomLetter = randomString(1, true);
 * const randomChar = randomString(1, true, true, true);
 * ```
 *
 * @param {number} length - length of generated string
 * @param {boolean} letters - Add letters to pool
 * @param {boolean} numbers - Add numbers to pool
 * @param {boolean} symbols - Add symbols to pool
 * @return {string} generated string
 */
export declare function randomStringBuilder(length: number, letters?: boolean, numbers?: boolean, symbols?: boolean): string;
/**
 * Find all substrings that match a given pattern.
 *
 * Roughly based on `String.prototype.matchAll`.
 *
 * @param {string} value - String to search.
 * @param {RegExp | string} regex - Regular expression to match.
 * @return {RegExpExecArray[]} Found matches.
 */
export declare function matchAll(value: string, regex: RegExp | string): RegExpExecArray[];
/** Parts of a URL */
export type ParsedUrl = {
    protocol?: string;
    subdomain?: string;
    domain: string;
    host: string;
    port?: number;
    path?: string;
    query?: {
        [name: string]: string;
    };
    fragment?: string;
};
/**
 * Break a URL string into its parts for easy parsing
 *
 * @param {string} url URL string that will be parsed
 * @returns {RegExpExecArray} Parts of URL
 */
export declare function parseUrl(url: string): ParsedUrl;
/**
 * Create MD5 hash using native javascript
 *
 * @param d String to hash
 * @returns {string} Hashed string
 */
export declare function md5(d: string): string;
/**
 * Check if email is valid
 *
 * @param {string} email - Target
 * @returns {boolean} - Follows format
 */
export declare function validateEmail(email: string): boolean;
